#
# spec file for package ghc-ReadArgs
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name ReadArgs
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.2.3
Release:        10.1
Summary:        Simple command line argument parsing
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-system-filepath-devel
BuildRequires:  ghc-text-devel
%if %{with tests}
BuildRequires:  ghc-hspec-devel
%endif

%description
ReadArgs provides the 'readArgs' IO action, which lets you tell the compiler to
parse the command line arguments to fit the type signature you give.

For example '(a :: Int, b :: String, c :: Float) <- readArgs' would parse the
first runtime argument as an 'Int', the second as a 'String' (no quotes
required) and the third as a 'Float'.

If the runtime arguments are incompatible with the type signature, then a
simple usage statement is given of the types needed.

Continuing the previous example, if it was used in a program named 'Example',
the error message for the above action would be:

' usage: Example Int String Float '

Any type that has both 'Typeable' and 'Read' instances can be used.
'Char', 'String', and 'Text' are handled specially so that command line
arguments for both do not require quotes (as their 'Read' instances do).
A special instance is provided for 'FilePath' so that no constructor or quotes
are required.

'readArgs' also supports optional arguments and variadic arguments.
Optional arguments are specified using 'Maybe', and variadic arguments using a
list. '(a :: Int, b :: Maybe String, c :: [Float]) <- readArgs' would
successfully parse any of the following sets of command line arguments:

' Example 1 Example 1 2 3 4 Example 1 foo Example 1 foo 2 3 4 '

But not

' Example Example foo Example 1.0 '

Usage statements for optional and variadic arguments use command-line parlance:

' usage: Example Int [String] [Float..] '

Note that both optional and variadic parsers are greedy by default (so 'Example
1 2 3 4' was parsed as '(1, "2", [3.0,4.0])'. They may both be made non-greedy
through use of the 'NonGreedy' constructor:

' ( a :: Int , NonGreedy b :: NonGreedy Maybe String , NonGreedy c :: NonGreedy
[] Float ) <- readArgs '.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE
%{_bindir}/ReadArgsEx

%files devel -f %{name}-devel.files

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Fri Dec 16 2016 psimons@suse.com
- Update to version 1.2.3 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.2.2 revision 0 with cabal2obs.
